@@ -1,6 +1,6 @@
 package Task::MapMetro::Dev;
 
-our $VERSION = '0.1000'; # VERSION
+our $VERSION = '0.1100'; # VERSION
 
 1;
 
@@ -18,47 +18,38 @@ Task::MapMetro::Dev - Everything useful when developing Map::Metro maps
 
 =head1 VERSION
 
-version 0.1000
+version 0.1100
 
 =head1 SYNOPSIS
 
-	# install graphviz.
-	# eg:
-	$ sudo apt-get install graphviz
+    # install graphviz.
+    # eg:
+    $ sudo apt-get install graphviz
 
-	# and then
+    # and then
     $ cpanm Task::MapMetro::Dev
 
 =head1 TASK CONTENTS
 
 =head2
 
-=head3 L<Map::Metro> 0.2002
-
 =head3 L<GraphViz2> 2.20
 
 =head3 L<Dist::Zilla> 5.000
 
-=head3 L<Dist::Zilla::MintingProfile::MapMetro::Map> 0.1200
+=head3 L<Map::Metro> 0.2203
+
+=head3 L<Dist::Zilla::MintingProfile::MapMetro::Map> 0.1401
 
 =head3 L<Dist::Zilla::Plugin::MapMetro::MakeGraphViz> 0.1100
 
+=head3 L<Dist::Zilla::Plugin::MapMetro::MakeLinePod> 0.1200
+
 =head1 SEE ALSO
 
 L<Map::Metro>
 
-=head1 AUTHOR
-
-Erik Carlsson E<lt>info@code301.comE<gt>
-
-=head1 COPYRIGHT
-
-Copyright 2015 - Erik Carlsson
-
-=head1 LICENSE
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+L<Task::MapMetro::Maps>
 
 =head1 AUTHOR
 
